summaryrefslogtreecommitdiff
path: root/src/buildstream/plugins
diff options
context:
space:
mode:
authorDarius Makovsky <traveltissues@protonmail.com>2020-01-13 09:06:11 +0000
committerJürg Billeter <j@bitron.ch>2020-02-11 21:08:59 +0100
commit1ee61a88bf0e3cbb0395153c681124990004e4ca (patch)
treeda47586dae6f3bb7bb16a239d25bd5c81ce95fb4 /src/buildstream/plugins
parent04c00da690bce67bd937a71dce5d84a338a0521f (diff)
downloadbuildstream-1ee61a88bf0e3cbb0395153c681124990004e4ca.tar.gz
_workspaces: Rename `last_successful` to `last_build`
The new incremental build approach uses the buildtree from the last build (successful or not) and no longer needs to know any information about the last successful build.
Diffstat (limited to 'src/buildstream/plugins')
-rw-r--r--src/buildstream/plugins/sources/workspace.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/buildstream/plugins/sources/workspace.py b/src/buildstream/plugins/sources/workspace.py
index f1ad2eead..13e2bb37d 100644
--- a/src/buildstream/plugins/sources/workspace.py
+++ b/src/buildstream/plugins/sources/workspace.py
@@ -55,16 +55,16 @@ class WorkspaceSource(Source):
self.__unique_key = None
# the digest of the Directory following the import of the workspace
self.__digest = None
- # the cache key of the last successful workspace
- self.__last_successful = None
+ # the cache key of the last workspace build
+ self.__last_build = None
def track(self) -> SourceRef: # pylint: disable=arguments-differ
return None
def configure(self, node: MappingNode) -> None:
- node.validate_keys(["path", "last_successful", "kind"])
+ node.validate_keys(["path", "last_build", "kind"])
self.path = node.get_str("path")
- self.__last_successful = node.get_str("last_successful")
+ self.__last_build = node.get_str("last_build")
def preflight(self) -> None:
pass # pragma: nocover